@@ -14,7 +14,7 @@ class AdvSettingsDlg : public QDialog
     Q_OBJECT
 
 public:
-    AdvSettingsDlg(QWidget *parent);
+    AdvSettingsDlg(QWidget *parent = 0);
     ~AdvSettingsDlg();
 
 private:
