@@ -60,32 +60,32 @@ MainWidget::~MainWidget()
 
 void MainWidget::sendCmdVolUp()
 {
-    irCtrl.sendCmd(settings->value("volUpCmd", "VOLUP").toString());
+    irCtrl.sendCmd(settings->value("cmd0", "VOLUP").toString());
 }
 
 void MainWidget::sendCmdVolDown()
 {
-    irCtrl.sendCmd(settings->value("volDownCmd", "VOLDOWN").toString());
+    irCtrl.sendCmd(settings->value("cmd1", "VOLDOWN").toString());
 }
 
 void MainWidget::sendCmdChUp()
 {
-    irCtrl.sendCmd(settings->value("chUpCmd", "CHUP").toString());
+    irCtrl.sendCmd(settings->value("cmd2", "CHUP").toString());
 }
 
 void MainWidget::sendCmdChDown()
 {
-    irCtrl.sendCmd(settings->value("chDownCmd", "CHDOWN").toString());
+    irCtrl.sendCmd(settings->value("cmd3", "CHDOWN").toString());
 }
 
 void MainWidget::sendCmdPower()
 {
-    irCtrl.sendCmd(settings->value("powerCmd", "POWER").toString());
+    irCtrl.sendCmd(settings->value("cmd4", "POWER").toString());
 }
 
 void MainWidget::sendCmdMute()
 {
-    irCtrl.sendCmd(settings->value("muteCmd", "MUTE").toString());
+    irCtrl.sendCmd(settings->value("cmd5", "MUTE").toString());
 }
 
 void MainWidget::paintEvent(QPaintEvent *)
