@@ -11,6 +11,7 @@
 #include <QByteArray>
 
 RemoteDBMgr::RemoteDBMgr()
+    : processing(false)
 {
     connect(&netAM, SIGNAL(finished(QNetworkReply *)), 
             this, SLOT(dbDownloadFinished(QNetworkReply *)));
@@ -51,7 +52,10 @@ void RemoteDBMgr::dbDownloadFinished(QNetworkReply *reply)
         if (!db.isEmpty()) {
             emit dbReady(&db);
         }
+    } else {
+        emit downloadFailed(reply->error());
     }
+
     processing = false;
 }
 
