@@ -2,7 +2,6 @@
 #define QNETWORKACCESSMANAGER_H
 
 #include <QObject>
-#include <QNetworkRequest>
 #include <QStringList>
 
 class QNetworkReply;
@@ -12,7 +11,7 @@ class QNetworkAccessManager : public QObject
     Q_OBJECT
 public:
     QNetworkAccessManager(QObject *parent = 0); 
-    QNetworkReply *get(const QNetworkRequest&);
+    QNetworkReply *get(const class QNetworkRequest&);
     static QStringList urls;
 
 signals:
@@ -20,3 +19,4 @@ signals:
 };
 
 #endif //QNETWORKACCESSMANAGER_H
+
