@@ -2,6 +2,7 @@
 #define QNETWORKREPLY_H
 
 #include <QByteArray>
+#include <QBuffer>
 
 class QNetworkReply
 {
@@ -18,6 +19,7 @@ public:
     void deleteLater();
     QByteArray readLine(qint64 maxlen = 0);
 
+    static QBuffer data;
 };
 
 #endif // QNETWORKREPLY_H
