@@ -1,7 +1,6 @@
 #ifndef _UT_REMOTEDBMGR_H_
 #define _UT_REMOTEDBMGR_H_
 
-#include "qnetworkreply.h"
 #include <QObject>
 #include <QWaitCondition>
 #include <QMutex>
@@ -30,9 +29,9 @@ private:
     void verifyRemotes(RemoteDB *db);
 
 private:
+    RemoteDBMgr *subject;
     QWaitCondition dbVerified;
     QMutex dbMutex;
-    RemoteDBMgr subject;
     RemoteDB validDB;
     bool dbOk;
     QDomDocument document;
